@@ -851,7 +851,7 @@ sub run_cc_test {
             if ($Config{ccversion} eq '12.0.8804') {
                 $command =~ s/ -opt:ref,icf//;
             }
-            $command .= " -Od" if $ENV{APPVEYOR};
+            $command .= " -Od" if $ENV{APPVEYOR} and $^O eq 'MSWin32';
             my $obj = $obj[0];
             $command =~ s/ \Q-o $exe\E / -c -Fo$obj /;
             my $cmdline = "$Config{cc} $command >NUL"; # need to silence it
@@ -868,10 +868,9 @@ sub run_cc_test {
            ." -L../.. -l$pkg ".$Config{libs}
           : ExtUtils::Embed::ldopts('-std');
         # At least cygwin gcc-4.3 crashes with 2x -fstack-protector
-        $linkargs =~ s/-fstack-protector\b//
-          if $linkargs !~ /-fstack-protector-strong\b/
-          and $command =~ /-fstack-protector\b/
-          and $linkargs =~ /-fstack-protector\b/;
+        $linkargs =~ s/-fstack-protector //
+          if $command =~ /-fstack-protector /
+          and $linkargs =~ /-fstack-protector /;
 
         if ($^O =~ /^(cygwin|MSWin32|msys)/) {
             if (index($command, "Win32CORE") < 0) {
@@ -886,7 +885,7 @@ sub run_cc_test {
                     $linkargs .= " $win32core";
                 }
             }
-            $linkargs .= " -Od" if $ENV{APPVEYOR};
+            $linkargs .= " -Od" if $ENV{APPVEYOR} and $^O eq 'MSWin32';
         }
 	if ( -e "$coredir/$libperl" and $libperl !~ /\.$so$/) {
 	    $command .= $linkargs;
