@@ -29,6 +29,7 @@ PERL=${PERL:-perl}
 PERL=`echo $PERL|sed -e's,^",,; s,"$,,'`
 v510=`$PERL -e'print (($] < 5.010)?0:1)'`
 v518=`$PERL -e'print (($] < 5.018)?0:1)'`
+v524=`$PERL -e'print (($] < 5.024)?0:1)'`
 #v522=`$PERL -e'print (($] < 5.022)?0:1)'`
 PERLV=v5.`$PERL -e'print substr($],3,2)'`
 XTESTC="t/CORE/$PERLV/C-COMPILED/xtestc"
@@ -118,7 +119,7 @@ function runopt {
 }
 
 function emit_test {
-  n=$1
+  n=$(expr $1 + 0)
   CONTENT="${tests[${n}]}"
   if [ "x$CONTENT" != "x" ]; then
     echo -E "$CONTENT"
@@ -129,7 +130,7 @@ function emit_test {
 }
 
 function make_t_symlink {
-  n=$1
+  n=$(expr $1 + 0)
   CONTENT="${tests[${n}]}"
   if [ "x$CONTENT" != "x" ]; then
     FILE_NUM=$(printf "%04d" $n)
@@ -149,7 +150,7 @@ function make_symlinks {
 }
 
 function ctest {
-    n=$1
+    n=$(expr $1 + 0)
     str=$2
 
     if [ $BASE = "testcc.sh" ]; then
@@ -531,6 +532,8 @@ tests[122]='my ($p1,$p2)=(80,80);if($p1<=23&&23<=$p2){print "telnet\n";}elsif ($
 result[122]='http'
 # issue52
 tests[123]='my $x;my $y = 1;$x and $y == 2;print $y == 1 ? "ok\n" : "fail\n";'
+# issue55
+tests[124]='LOOP:{my $sub=sub{last LOOP;}; $sub->() } print "ok";'
 # issue125 DynaLoader::bootstrap_inherit [perl #119577]
 tests[125]='use Net::LibIDN; print q(ok);'
 # saving recursive functions sometimes recurses in the compiler. this not, but Moose stucks in Pod::Simple
@@ -564,8 +567,10 @@ tests[144]='print index("long message\0xx","\0")'
 result[144]='12'
 tests[145]='my $bits = 0; for (my $i = ~0; $i; $i >>= 1) { ++$bits; }; print $bits'
 result[145]=`$PERL -MConfig -e'print 8*$Config{ivsize}'`
-tests[146]='my $a = v120.300; my $b = v200.400; $a ^= $b; print sprintf("%vd", $a);'
-result[146]='176.188'
+if [[ $v524 -eq 0 ]]; then # Use of strings with code points over 0xFF as arguments to bitwise xor (^) operator is deprecated in perl 5.24
+  tests[146]='my $a = v120.300; my $b = v200.400; $a ^= $b; print sprintf("%vd", $a);'
+  result[146]='176.188'
+fi
 tests[148]='open(FH, ">", "ccode148i.tmp"); print FH "1\n"; close FH; print -s "ccode148i.tmp"'
 result[148]='2'
 tests[149]='format Comment =
@@ -709,8 +714,10 @@ ok'
 tests[176]='use Math::BigInt; print Math::BigInt::->new(5000000000);'
 result[176]='5000000000'
 tests[177]='use version; print "ok\n" if version::is_strict("4.2");'
-tests[178]='BEGIN { $hash  = { pi => 3.14, e => 2.72, i => -1 } ;} print scalar keys $hash;'
-result[178]='3'
+if [[ $v524 -eq 0 ]]; then
+  tests[178]='BEGIN { $hash  = { pi => 3.14, e => 2.72, i => -1 } ;} print scalar keys $hash;'
+  result[178]='3'
+fi
 tests[179]='#TODO smartmatch subrefs
 {
     package Foo;
@@ -1199,7 +1206,7 @@ package B1; our @ISA = qw/D1/;
 package A1; use mro "c3"; our @ISA = qw/B1 C1/; sub testmeth { shift->next::method }
 A1->testmeth() eq "right" and print "ok\n"'
 fi
-if [[ $v518 -gt 0 ]]; then
+if [[ $v518 -gt 0 && $v524 -eq 0 ]]; then
   tests[299]='no warnings qw{experimental::lexical_topic}; my $s = "ok\n"; my $_ = "not ok\n"; my $r = $s =~ /ok(?{ print qq[$_] })/;'
 fi
 tests[2990]='#TODO version
@@ -1411,6 +1418,37 @@ tests[3300]='#WONTFIX
 tests[3301]='#WORKAROUND 3300
 IO::Handle->new if $ENV{none}; *STDOUT; sub IO::Handle::self { $_[0] };
 (*STDOUT->self . "") =~ m/^GLOB/ and print "ok\n"'
+tests[367]='#BROKEN since 5.22 (METHOP for binc)
+use Math::BigInt;
+my $x = Math::BigInt->new('1' x 20);
+print "ok" if ++$x eq "11111111111111111112";'
+tests[390]='print test(); print test();
+sub test() {
+    *test = sub ()  { "k" };
+    "o";
+}'
+tests[391]='use warnings "closed"; eval "warn qq(\n); print qq(ok\n)";'
+tests[400]='#TODO
+use Class::XSAccessor constructor => "new", accessors => [ "foo" ];
+my $o = main::->new( foo => "ok" );
+print $o->foo,"\n";'
+tests[4001]='require Class::XSAccessor;
+Class::XSAccessor->import(constructor => "new", accessors => [ "foo" ]);
+my $o = main::->new( foo => "ok" );
+print $o->foo,"\n";'
+tests[4002]='use Class::XSAccessor;
+Class::XSAccessor->import(constructor => "new", accessors => [ "foo" ]);
+my $o = main::->new( foo => "ok" );
+print $o->foo,"\n";'
+tests[411]='#TODO run-time regcomp of \p{}
+our ( $q, $myre );
+BEGIN { $q = qr[\p{IsWord}] }
+eval q/$myre = qr[^$q]/; # add ^ to force the RegExp to be recompiled
+print qq[ok\n] if q[hello] =~ $myre;'
+tests[4111]='our ( $q, $myre );
+BEGIN { $q = qr[\p{IsWord}] }
+eval q/$myre = qr[$q]/; # this works
+print qq[ok\n] if q[hello] =~ $myre;'
 
 init
 
